getdists: Calculate segment lengths and total line length

Description Usage Arguments

View source: R/SG.R

Description

Calculate segment lengths and total line length

Usage

1
getdists(coords)

Arguments

coords

A matrix of x (first column) and y (second column) coordinates of vertices along a line.

Calculates the segment length of each segment along a multipart line from the coordinates of the vertices of that line using the equation sqrt((x2 - x1)^2 + sqrt(y2 - y1)^2)


trevorjwilli/streamgradientR documentation built on Dec. 31, 2020, 8:46 a.m.