getupdown: Calculate the x and y values of points a specified distance...

Description Usage Arguments Details

View source: R/SG.R

Description

Calculate the x and y values of points a specified distance upstream and downstream a point on a line

Usage

1
getupdown(points, lines, seglength, idcol = NULL)

Arguments

points

A SpatialPointsDataFrame in a planar projection

lines

A SpatialLinesDataFrame in a planar projection

seglength

Numeric 1L The distance upstream and downstream to calculate new points

idcol

Character, optional column name for an identification column from points input

Details

This function calculates the x and y values that are d units away from points a known distance along a lines spatial object. NOTE: it will only work if the input spatial data are in a planar projection (i.e. UTM).


trevorjwilli/streamgradientR documentation built on Dec. 31, 2020, 8:46 a.m.