Description Usage Arguments Details
Calculate gradient between two points on stream
1 |
points |
Data Frame, output from getupdown function or same format as output from getupdown function |
ras |
Raster of DEM. Works best if it is in the same projection as original points and lines shapefiles used to calculate the stationing. |
fctr |
Factor to multiply the segment length by. For example, if lengths are in meters and you want gradient in meters/km fctr must be 0.001 |
Calculates the stream gradient of segments on a line delimited by an upstream and downstream point. This function works best if the points input is directly used from the output of the getupdown function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.