Calculate segment lengths and total line length
1 | getdists(coords)
|
coords |
A matrix of x (first column) and y (second column) coordinates of vertices along a line. Calculates the segment length of each segment along a multipart line from the coordinates of the vertices of that line using the equation sqrt((x2 - x1)^2 + sqrt(y2 - y1)^2) |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.