Description Usage Arguments Details
Calculate the x and y values of points a specified distance upstream and downstream a point on a line
1 |
points |
A SpatialPointsDataFrame in a planar projection |
lines |
A SpatialLinesDataFrame in a planar projection |
seglength |
Numeric 1L The distance upstream and downstream to calculate new points |
idcol |
Character, optional column name for an identification column from points input |
This function calculates the x and y values that are d units away from points a known distance along a lines spatial object. NOTE: it will only work if the input spatial data are in a planar projection (i.e. UTM).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.